---
title: "White space in menu entry"
date: 2017-07-19
tags: ["menu", "yaml"]
draft: false
menu:
  "something here":
    identifier: "white-space-in-menu-entry"
    weight: 25
---

Testing the addition of _menu_ meta data to the YAML front matter.
Here the front matter format is set to YAML using the
`HUGO_FRONT_MATTER_FORMAT` key in property drawer.

Here there is white space in menu entry keyword.
